## $Id: interfaces.py 7880 2012-03-14 15:39:49Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from waeup.kofa.interfaces import (
    ISessionConfiguration, academic_sessions_vocab)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.custom')

# It's recommended to replicate all fields from the base package here.
class ISessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    school_fee_base = schema.Int(
        title = _(u'School Fee (ignored)'),
        default = 0,
        required = False,
        )

    surcharge_1 = schema.Int(
        title = _(u'Surcharge Portal Provider'),
        default = 0,
        required = False,
        )

    surcharge_2 = schema.Int(
        title = _(u'Surcharge Interswitch'),
        default = 0,
        required = False,
        )

    surcharge_3 = schema.Int(
        title = _(u'Surcharge 3'),
        default = 0,
        required = False,
        )

    clearance_fee = schema.Int(
        title = _(u'Clearance Fee'),
        default = 0,
        required = False,
        )

    booking_fee = schema.Int(
        title = _(u'Booking Fee'),
        default = 0,
        required = False,
        )

    acceptance_fee = schema.Int(
        title = _(u'Acceptance Fee'),
        default = 0,
        required = False,
        )

    # Additional fees in waeup.custom

    maint_fee = schema.Int(
        title = _(u'Maintenance Fee'),
        default = 0,
        required = False,
        )

    gown = schema.Int(
        title = _(u'Gown Fee'),
        default = 0,
        required = False,
        )

    transfer = schema.Int(
        title = _(u'Transfer Fee'),
        default = 0,
        required = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ISessionConfigurationAdd(ISessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ISessionConfigurationAdd['academic_session'].order =  ISessionConfiguration[
    'academic_session'].order